@@ -171,11 +171,19 @@ async def test_close_session(nw: Network):
 
 
 @pytest.mark.parametrize(
-    "api_kind, network_name,expected", [
+    "api_kind, network_name, expected", [
         ('eth', 'main', 'https://api.etherscan.io/api'),
         ('eth', 'kovan', 'https://api-kovan.etherscan.io/api'),
         ('bsc', 'main', 'https://api.bscscan.com/api'),
         ('bsc', 'testnet', 'https://api-testnet.bscscan.com/api'),
+        ('avax', 'main', 'https://api.snowtrace.io/api'),
+        ('avax', 'testnet', 'https://api-testnet.snowtrace.io/api'),
+        ('polygon', 'main', 'https://api.polygonscan.com/api'),
+        ('polygon', 'testnet', 'https://api-testnet.polygonscan.com/api'),
+        ('optimism', 'main', 'https://api-optimistic.etherscan.io/api'),
+        ('optimism', 'testnet', 'https://api-testnet-optimistic.etherscan.io/api'),
+        ('arbitrum', 'main', 'https://api.arbiscan.io/api'),
+        ('arbitrum', 'testnet', 'https://api-testnet.arbiscan.io/api'),
     ]
 )
 def test_test_network(api_kind, network_name, expected):
